Monitoring
==========

.. toctree::
    :maxdepth: 3

    grp_monitoring_metric_types
    grp_monitoring_pushers
    grp_monitoring_collectors


.. automodule:: uwsgiconf.options.monitoring
   :members:
